| branch_distribution_plot | R Documentation |
Generates a diagnostic plot showing the distribution of branch diameters in a QSM. This is a wrapper around 'branch_size_distribution()' which computes branch metrics.
branch_distribution_plot(qsm)
qsm |
A QSM object (e.g., data frame returned by 'run_treeqsm()') containing cylinder information. |
The function calls 'branch_size_distribution()' with 'plot = FALSE' to compute branch volumes at midpoints of diameter bins, then generates a bar plot showing total volume per diameter bin.
A 'ggplot' object displaying branch diameter (x-axis) versus total branch volume (y-axis).
qsm_file = system.file('extdata',"tree_0744_qsm.txt", package='tReeTraits')
qsm = load_qsm(qsm_file)
branch_distribution_plot(qsm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.