clean_las: Load, Recenter, and Remove low vegetation from 'LAS' object...

View source: R/preprocessing.R

clean_lasR Documentation

Load, Recenter, and Remove low vegetation from 'LAS' object representing segmented tree

Description

Function to normalize, remove noise, remove vegetation, and recenter 'LAS' representing segmented tree. Vegetation cleaning is accomplished by identifying stem points (CrownScrochTLS::StemPoints) and removing all but the Stem below the 'z.threshold'.

Usage

clean_las(las, bole_height = 1, quantile = 0.001)

Arguments

las

'LAS' object from 'lidR' package representing individually segmented tree

bole_height

numeric, height threshold below which all stem points can be considered vegetation.

quantile

See 'normalize_las'. Z quantile at which grown level is specified since ground points may not be identifiable with common algorithms if ground points are removed during segmentation#'

Value

A cleaned 'LAS' object with vegetation and noise removed, normalized and recentered.

Examples

library(lidR)
las = readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las_cleaned = clean_las(las)

plot(las)
plot(las_cleaned)


tReeTraits documentation built on Feb. 26, 2026, 1:07 a.m.