convex_hull_2D: Returns the convex hull representing vertical crown area

View source: R/traits_from_point_cloud.R

convex_hull_2DR Documentation

Returns the convex hull representing vertical crown area

Description

This function generates an 'sf' object representing th vertical crown area of a 'LAS' object based using the convex hull of a 2D vertical projection.

Usage

convex_hull_2D(las, angle = 0)

Arguments

las

'LAS' object from 'lidR' package representing the CROWN of a tree. Crowns must be segmented using [segment_crown()].

angle

numeric - in degrees, rotation angle about Z axis.

Value

An 'sf' polygon representing the vertical convex hull of the crown projection.

Examples

las = lidR::readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las = clean_las(las)
cbh = get_crown_base(las, threshold=0.25, sustain=2)
las = segment_crown(las, cbh)
get_crown_volume_voxel(las)
get_crown_volume_alpha(las)
sf::st_area(convex_hull_2D(las)) #profile area, convex hull
sf::st_area(voxel_hull_2D(las)) #profile area, voxel hull
get_lacunarity(las)

tReeTraits documentation built on Feb. 26, 2026, 1:07 a.m.