get_area_profile: Generate area estimates of tree profile in segments

View source: R/traits_from_point_cloud.R

get_area_profileR Documentation

Generate area estimates of tree profile in segments

Description

This function calculates the area of the tree profile by breaking it into segments of height 'segment_height' and estimating the width of each segement. Area profiles are useful for caluclating total area, but also used to detect crown base height.

Usage

get_area_profile(las, segment_height = 0.25, quantile = c(0.001), angle = 0)

Arguments

las

'LAS' object from 'lidR' package representing individually segmented tree, with the crown labeled.

segment_height

numeric - height of each segment in which to calculate area

quantile

numeric - quantile at which width is measured Values in the interval approaching 0 (e.g., 0.001) are recommended to trim random noise

angle

numeric - angle at which to rotate the point cloud prior to estimating area. Useful in a loop if quantifying mulitple angles

Value

A tibble with columns 'bottom', 'top', 'width', 'area', and 'angle' describing the vertical area profile.


tReeTraits documentation built on Feb. 26, 2026, 1:07 a.m.