get_height: Extract height from 'LAS' object representing segmented tree.

View source: R/traits_from_point_cloud.R

get_heightR Documentation

Extract height from 'LAS' object representing segmented tree.

Description

Function to extract height from LAS object. Function calculates difference between two specified quantiles from the 'Z' attribute.

Usage

get_height(las, quantiles = c(0, 1))

Arguments

las

'LAS' object from 'lidR' package representing individually segmented tree

quantiles

Z quantiles at which ground level and highest point are measured. Values in the interval (0,1) are recommended to trim random noise.

Value

A named numeric vector with element 'height' (m).

Examples

library(lidR)
las = readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las = clean_las(las)
print(get_height(las))

tReeTraits documentation built on Feb. 26, 2026, 1:07 a.m.