plot_qsm2d: Plot QSM in base R

View source: R/diagnostics.R

plot_qsm2dR Documentation

Plot QSM in base R

Description

Simple function to create a diagnostic plot to view QSMs colored by branching order.

Usage

plot_qsm2d(qsm, scale = 150, rotation = TRUE)

Arguments

qsm

a QSM loaded using '[load_qsm()]'.

scale

a factor by which to multiply the 'radius_cyl' column to give line segments the appearance of volume

rotation

boolean - indicates whether the plot should display the tree from 2 angles TRUE, or just one FALSE.

Value

'NULL', invisibly. Produces a base R plot as a side effect.

Examples

qsm_file = system.file("extdata", "tree_0744_qsm.txt", package='tReeTraits')
qsm = load_qsm(qsm_file)
plot_qsm2d(qsm)

tReeTraits documentation built on Feb. 26, 2026, 1:07 a.m.