plot_tree: Make 3-panel plot of tree point cloud to check for errors

View source: R/diagnostics.R

plot_treeR Documentation

Make 3-panel plot of tree point cloud to check for errors

Description

Plots 2 profiles X, Y, and and overhead Z view of a point cloud to allow users to identify stray points, or errors in segmentations.

Usage

plot_tree(las, res = 0.05, plot = TRUE)

Arguments

las

'LAS' object from 'lidR' package representing the CROWN of a tree. Crowns can be segmented using [segment_crown()].

res

numeric - resolution of voxelization to speed up plotting

plot

boolean - indicates whether to print the output plot, in both cases a ggplot object is returned in the output.

Value

A 'ggplot' object containing the arranged diagnostic panels.

Examples

# example code
library(lidR)
file = system.file("extdata", "tree_0744.laz", package="tReeTraits")
las = readLAS(file, filter = '-thin_with_voxel 0.1')
las = clean_las(las)
plot_tree(las)

tReeTraits documentation built on Feb. 26, 2026, 1:07 a.m.