View source: R/pytlidar-setup.R
| setup_pytlidar | R Documentation |
Ensures Python 3.11 is available via conda, creates 'r-reticulate-pytlidar' environment if needed, activates it, and installs required Python modules for PyTLidar.
setup_pytlidar()
This function **must be called manually** before using any Python-dependent functions.
'TRUE' if the environment is successfully activated and all required Python modules are available, 'FALSE' if installation of Miniconda was required and R should be restarted.
## Not run:
setup_pytlidar()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.