View source: R/preprocessing.R
| clean_las | R Documentation |
Function to normalize, remove noise, remove vegetation, and recenter 'LAS' representing segmented tree. Vegetation cleaning is accomplished by identifying stem points (CrownScrochTLS::StemPoints) and removing all but the Stem below the 'z.threshold'.
clean_las(las, bole_height = 1, quantile = 0.001)
las |
'LAS' object from 'lidR' package representing individually segmented tree |
bole_height |
numeric, height threshold below which all stem points can be considered vegetation. |
quantile |
See 'normalize_las'. Z quantile at which grown level is specified since ground points may not be identifiable with common algorithms if ground points are removed during segmentation#' |
A cleaned 'LAS' object with vegetation and noise removed, normalized and recentered.
library(lidR)
las = readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las_cleaned = clean_las(las)
plot(las)
plot(las_cleaned)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.