View source: R/traits_from_point_cloud.R
| get_area_profile | R Documentation |
This function calculates the area of the tree profile by breaking it into segments of height 'segment_height' and estimating the width of each segement. Area profiles are useful for caluclating total area, but also used to detect crown base height.
get_area_profile(las, segment_height = 0.25, quantile = c(0.001), angle = 0)
las |
'LAS' object from 'lidR' package representing individually segmented tree, with the crown labeled. |
segment_height |
numeric - height of each segment in which to calculate area |
quantile |
numeric - quantile at which width is measured Values in the interval approaching 0 (e.g., 0.001) are recommended to trim random noise |
angle |
numeric - angle at which to rotate the point cloud prior to estimating area. Useful in a loop if quantifying mulitple angles |
A tibble with columns 'bottom', 'top', 'width', 'area', and 'angle' describing the vertical area profile.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.