View source: R/traits_from_qsm.R
| get_com_offset | R Documentation |
This function extracts the horizontal distance between the base of a tree and the center of a tree from a QSM. The function takes the coordinate of the lowest QSM segment, and the center of mass, and finds the horizontal distance between them.
get_com_offset(qsm)
qsm |
a QSM loaded using '[load_qsm()]'. |
A single numeric value giving the horizontal distance (m) between the base of the tree and the volume-weighted center of mass.
qsm_file = system.file("extdata", "tree_0744_qsm.txt", package='tReeTraits')
qsm = load_qsm(qsm_file)
print(get_center_of_mass(qsm))
print(get_com_offset(qsm))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.