View source: R/traits_from_point_cloud.R
| get_crown_volume_alpha | R Documentation |
This function volume of a 'LAS' object by thinning to a resolution specified by 'resolution', and estimating volume by fitting a alpha shape volume. Crowns must be segmented using [segment_crown()].
get_crown_volume_alpha(las, resolution = 0.1, alpha = 0.5)
las |
'LAS' object from 'lidR' package representing a tree. Crowns must be segmented using [segment_crown()]. |
resolution |
numeric - resolution of initial voxelization to increase speed |
alpha |
numeric - alpha for the computation of the 3D alpha-shape of the point cloud. See [alphashape3d::ashape3d]. |
A named numeric vector with element 'crown_volume_alpha' (m^3).
las = lidR::readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
cbh = get_crown_base(las, threshold=0.25, sustain=2)
las = segment_crown(las, cbh)
get_crown_volume_voxel(las)
get_crown_volume_alpha(las)
sf::st_area(convex_hull_2D(las)) #profile area, convex hull
sf::st_area(voxel_hull_2D(las)) #profile area, voxel hull
get_lacunarity(las)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.