View source: R/traits_from_point_cloud.R
| get_dbh | R Documentation |
Function to extract diameter at breast height (1.37 m) from LAS object. Function filters LAS keeping only points with Intensity greater than specified threshold. Function calculates verticality eigenvalue and filters based on verticality threshold. Last, diameter is calculated using a RANSAC cylinder fitting algorithm.
get_dbh(
las,
intensity_threshold = 41000,
select_n = 10,
verticality_threshold = 0.9
)
las |
'LAS' object from 'lidR' package representing individually segmented tree |
intensity_threshold |
numeric - filter value for Intensity to help remove vegetation |
select_n |
numeric - number of points selected on every RANSAC iteration. |
verticality_threshold |
numeric - filter value for Verticality threshold to remove horizontal branches. |
A named numeric vector with element 'dbh' (m).
library(lidR)
las = readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las = clean_las(las)
print(get_dbh(las))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.