View source: R/traits_from_point_cloud.R
| get_height | R Documentation |
Function to extract height from LAS object. Function calculates difference between two specified quantiles from the 'Z' attribute.
get_height(las, quantiles = c(0, 1))
las |
'LAS' object from 'lidR' package representing individually segmented tree |
quantiles |
Z quantiles at which ground level and highest point are measured. Values in the interval (0,1) are recommended to trim random noise. |
A named numeric vector with element 'height' (m).
library(lidR)
las = readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las = clean_las(las)
print(get_height(las))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.