View source: R/traits_from_qsm.R
| get_stem_tilt | R Documentation |
This function calculates tilt of a tree from a QSM. The function identifies the upper and lower extreme segments of the QMS (trunk sections only) and computes a vector between them, and returns the devation of that angle from directly vertical.
get_stem_tilt(qsm, terminus_diam_cm = 4)
qsm |
a QSM loaded using '[load_qsm()]'. |
terminus_diam_cm |
numeric - trunk diameter at which it is treated as a branch. |
A single numeric value giving stem tilt in degrees from vertical.
qsm_file = system.file("extdata", "tree_0744_qsm.txt", package='tReeTraits')
qsm = load_qsm(qsm_file)
get_stem_tilt(qsm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.