View source: R/traits_from_point_cloud.R
| get_width | R Documentation |
Function to extract width from LAS object. Function calculates difference between two specified quantiles from the 'X' and 'Y' attributes and returns both widths and their average.
get_width(las, quantiles = c(0.001, 0.999))
las |
'LAS' object from 'lidR' package representing individually segmented tree |
quantiles |
Z quantiles at which widths are measured are measured. Values in the interval (0,1) are recommended to trim random noise. |
A named numeric vector with elements 'mean_width', 'x_width', and 'y_width' (m).
library(lidR)
las = readLAS(system.file("extdata", "tree_0744.laz", package="tReeTraits"))
las = clean_las(las)
print(get_width(las))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.