| plot_qsm2d | R Documentation |
Simple function to create a diagnostic plot to view QSMs colored by branching order.
plot_qsm2d(qsm, scale = 150, rotation = TRUE)
qsm |
a QSM loaded using '[load_qsm()]'. |
scale |
a factor by which to multiply the 'radius_cyl' column to give line segments the appearance of volume |
rotation |
boolean - indicates whether the plot should display the tree from 2 angles TRUE, or just one FALSE. |
'NULL', invisibly. Produces a base R plot as a side effect.
qsm_file = system.file("extdata", "tree_0744_qsm.txt", package='tReeTraits')
qsm = load_qsm(qsm_file)
plot_qsm2d(qsm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.